CoPlot
======

CoPlot is a personal plotting library that commonly used in the research of cosmology and astrophysics. It contains many commonly used plotting modules.

It will be updated according to the research progress of the researcher. Its goal is to achieve the most complex and perfect drawings with minimal code.

If you find it useful, enjoy it!


Dependencies
============

* os
* numpy
* scipy
* math
* matplotlib
* logging


Installation
------------

$ sudo pip install coplot-master.zip

or

$ sudo python setup.py install


License
-------

Copyright 2020-2020 Guojian Wang

coplot is free software made available under the MIT License. For details see the LICENSE file.
